#Pokesel
es una libreria para generar un pokemon aleatorio

##Instalacion
Para instalar la lbreria tienes que usar ´pip install pokesel´

#Uso 
Aqui hay un ejemplo de como puedes utilizar la biblioteca para obtener informacion sobre pokemon

#Crear una instancia de RandomPokemon
pokemon = RandomPokemon()
#Generar un pokemon aleatorio
pokemon generate_random()

#Obtener el nombre del pokemon generado
pokemon_name=pokemon.getName()

#Imprimir el nombre de un pokemon
print("Nombre del Pokemon",pokemon_name)

#Archivo CSV de Pokemon
La biblioteca utiliza un archivo CSV llamado Pokemon csv que contiene datos de Pokemon necesitas acceder al archivo pokemon.csv directamente,puedes encontrarlo en el directorio

#Autor
Selene Garcia

